part of '../../public.dart';

class ERPAPI extends APIMethods<ERPTokenModel> {
  static late final ERPAPI instance;

  static Future init({
    required String serverURL,
    VoidCallback? onClosing,
    VoidCallback? onOpening,
    int timeoutMinutes = 1,
    VoidCallback? onTimeout,
  }) async {
    assert(timeoutMinutes > 0);
    final GetStorage publicStorage = GetStorage("$serverURL/Public"
        .replaceAll(":", "")
        .replaceAll(".", "")
        .replaceAll("-", "")
        .replaceAll("/", ""));
    await publicStorage.initStorage;

    instance = ERPAPI(
        serverURL: serverURL,
        publicStorage: publicStorage,
        onOpening: onOpening ?? () {},
        onClosing: onClosing ?? () {},
        timeoutMinutes: timeoutMinutes,
        onTimeout: onTimeout,
        // deviceId: (await PlatformDeviceId.getDeviceId)?.trim() ??
        //     'Failed to get deviceId.',
        deviceId: "77498118-FA47-AB41-B93A-C68C9940D615");
  }

  final String deviceId;
  DateTime lastOperation = DateTime.now();
  final int timeoutMinutes;
  final VoidCallback? onTimeout;


  ERPAPI({
    required super.serverURL,
    required super.publicStorage,
    required super.onClosing,
    required super.onOpening,
    required this.deviceId,
    int timeoutMinutes = 5,
    this.onTimeout,
  }) : timeoutMinutes = timeoutMinutes.abs();

  @override
  Future privateStorageBuild(ERPTokenModel tokenModel) async {
    final storage = GetStorage(
      "$serverURL/${tokenModel.id}"
          .replaceAll(":", "")
          .replaceAll("-", "")
          .replaceAll(".", "")
          .replaceAll("/", ""),
    );
    await storage.initStorage;
    privateStorage.value = storage;
  }

  @override
  Future<APIResponse<Map<String, dynamic>>> post(String path,
      {required Map<String, dynamic> data}) async {
    lastOperation = DateTime.now();
    return super.post(path, data: data);
  }
}
